tools Package
=============

These commandline-tools are installed into :samp:`{INSTALL_PREFIX}/bin` by setuptools.

:mod:`tools` Package
---------------------

.. automodule:: rdflib.tools
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`csv2rdf` Module
---------------------

.. automodule:: rdflib.tools.csv2rdf
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: __dict__,__weakref__

:mod:`graphisomorphism` Module
------------------------------

.. automodule:: rdflib.tools.graphisomorphism
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`rdf2dot` Module
---------------------

.. automodule:: rdflib.tools.rdf2dot
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`rdfpipe` Module
---------------------

.. automodule:: rdflib.tools.rdfpipe
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`rdfs2dot` Module
----------------------

.. automodule:: rdflib.tools.rdfs2dot
    :members:
    :undoc-members:
    :show-inheritance:

